from kof_api.Chestplate import Chestplate

from kof_api.Math import Math

math = Math()

class LeatherLamellar(Chestplate):
	def __init__(self):
		self.name = "Leather Lamellar Chestplate"
		self.defense = 1.2
		self.weight = math.convert_kg_lb(5)
		self.desc = "Body armour, made from small rectangular plates of  leather laced into horizontal rows."
		
		super().__init__(self.name, self.defense, self.weight)