class CCN:
	def __init__(self):
		self.city_names = [
		"Valhalla", "Obra", "Katha", "Ebliytan",
		"Atrye", "Jachiuca", "Kashuqua", "Ashye",
		"Ostrus", "Jebral", "Breos Breau", "Hosmein",
		"Qacheaji", "Yaswabia", "Quswuestein", "Lowhye",
		"Getra", "Broele", "Mesnounia", "Ushax", "Shiu Crax",
		"Shiutan", "Zubliuburg", "Aswein", "Esmana", "Fochye",
		"Friebar", "Ieskaca", "Keswary", "Fliyla", "Sheistein",
		"Estrington", "Freador", "Craenia", "Skeoburg"
		]
		
		self.region_names = [
		"Terra", "Asgard", "Valyrie"
		]
		
		self.npc_names = [
			"Barb", "Oliver", "Arthur", "Edith", "Henry",
			"Isabel", "Eleanor", "Elizabeth", "Arne",
			"Bahram", "Björn", "Daegal", "Cyprian",
			"Elric", "Galileo", "Gandalf", "Gregory",
			"Kazamir", "Lancaster", "Leif", "Morcant",
			"Njal", "Odel", "Osric", "Randolf", "Svend",
			"Amelia", "Beatriz", "Olive", "Petra", "Colette",
			"Diamond", "Eira", "Jacquette", "Sigrid", "Bogdana",
			"Celestina", "Brenna", "Mathilda", "Anastasia", "Astrid",
			"Yrsa"
			
			
		]