class Item:
	def __init__(self, name, type, equip_type, atk, defense, weight):
		self.name = name
		self.type = type
		self.equip_type = equip_type
		self.atk = atk
		self.defense = defense
		self.weight = weight